@@ -93,8 +93,9 @@ def get_article_form():
     article_form = config.get('form_instance')
     if not article_form:
         form_path = config.get('form', 'smallpress.lib.forms.ArticleForm')
-        root_module, path = form_path.split('.', 1)
-        form_class = reduce(getattr, path.split('.'), sys.modules[root_module])
+        module, form_name = form_path.rsplit('.', 1)
+        module = __import__(module, fromlist=form_name)
+        form_class = getattr(module, form_name)
         article_form = config['form_instance'] = form_class()
 
     return article_form
